@@ -2,7 +2,7 @@
 # General Public License as published by the Free Software Foundation, either
 # version 3 of the License, or (at your option) any later version.
 # See the "COPYING" file for details.
-package HTML::Blitz::SelectorType;
+package HTML::Blitz::SelectorType 0.1001;
 use HTML::Blitz::pragma;
 use Exporter qw(import);
 use HTML::Blitz::Atom our @EXPORT_OK = qw(
@@ -24,6 +24,4 @@ use HTML::Blitz::Atom our @EXPORT_OK = qw(
     LT_ADJACENT_SIBLING
 );
 
-our $VERSION = '0.0901';
-
 1
