@@ -2,7 +2,7 @@
 # General Public License as published by the Free Software Foundation, either
 # version 3 of the License, or (at your option) any later version.
 # See the "COPYING" file for details.
-package HTML::Blitz::TokenType;
+package HTML::Blitz::TokenType 0.1001;
 use HTML::Blitz::pragma;
 use Exporter qw(import);
 use HTML::Blitz::Atom our @EXPORT_OK = qw(
@@ -13,6 +13,4 @@ use HTML::Blitz::Atom our @EXPORT_OK = qw(
     TT_DOCTYPE
 );
 
-our $VERSION = '0.0901';
-
 1
