@@ -2,11 +2,12 @@
 # General Public License as published by the Free Software Foundation, either
 # version 3 of the License, or (at your option) any later version.
 # See the "COPYING" file for details.
-package HTML::Blitz::pragma;
+package HTML::Blitz::pragma 0.1001;
 use strict;
 use warnings qw(all FATAL uninitialized);
 use constant {
     PERL_VERSION    => '5.20',
+    _HAVE_PERL_5_24 => $^V ge v5.24.0,
     _HAVE_PERL_5_32 => $^V ge v5.32.0,
 };
 use feature ':' . PERL_VERSION;
@@ -15,8 +16,6 @@ use Function::Parameters 2;
 
 use Carp ();
 
-our $VERSION = '0.0901';
-
 method import($class: @items) {
     for my $item (@items) {
         Carp::croak qq("$item" is not exported by the $class module);
@@ -24,7 +23,8 @@ method import($class: @items) {
 
     strict->import;
     warnings->import(qw(all FATAL uninitialized));
-    feature->import(':' . PERL_VERSION);
+    warnings->unimport(qw(experimental::postderef)) unless _HAVE_PERL_5_24;
+    feature->import(':' . PERL_VERSION, 'postderef');
     feature->unimport('indirect') if _HAVE_PERL_5_32;
     Function::Parameters->import;
 }
